@@ -21,22 +21,18 @@
 
 from __future__ import annotations
 
-import logging
-
 from typing import TYPE_CHECKING
 
-import click
-
+from molecule.click_cfg import click_command_ex, common_options
 from molecule.command import base
 
 
 if TYPE_CHECKING:
+    import click
+
     from molecule.types import CommandArgs
 
 
-LOG = logging.getLogger(__name__)
-
-
 class SideEffect(base.Base):
     """This action has side effects and not enabled by default.
 
@@ -52,36 +48,32 @@ class SideEffect(base.Base):
         if self._config.provisioner:
             if not self._config.provisioner.playbooks.side_effect:
                 msg = "Skipping, side effect playbook not configured."
-                LOG.warning(msg)
+                self._log.warning(msg)
                 return
 
             self._config.provisioner.side_effect(action_args)
 
 
-@base.click_command_ex()
-@click.pass_context
-@base.click_command_options
-def side_effect(
-    ctx: click.Context,
-    /,
-    scenario_name: list[str] | None,
-    exclude: list[str],
-    *,
-    __all: bool,
-    report: bool,
-) -> None:  # pragma: no cover
-    """Use the provisioner to perform side-effects to the instances.
+@click_command_ex()
+@common_options()
+def side_effect(ctx: click.Context) -> None:  # pragma: no cover
+    """Use the provisioner to perform side effects to the role.
 
     Args:
         ctx: Click context object holding commandline arguments.
-        scenario_name: Name of the scenario to target.
-        exclude: Name of the scenarios to avoid targeting.
-        __all: Whether molecule should target scenario_name or all scenarios.
-        report: Whether to show an after-run summary report.
     """
     args = ctx.obj.get("args")
     subcommand = base._get_subcommand(__name__)  # noqa: SLF001
-    command_args: CommandArgs = {"subcommand": subcommand, "report": report}
+    command_args: CommandArgs = {
+        "report": ctx.params["report"],
+        "shared_inventory": ctx.params["shared_inventory"],
+        "shared_state": ctx.params["shared_state"],
+        "subcommand": subcommand,
+    }
+
+    __all = ctx.params["all"]
+    exclude = ctx.params["exclude"]
+    scenario_name = ctx.params["scenario_name"]
 
     if __all:
         scenario_name = None
